from setuptools import setup, find_packages

setup(
    name="helper_module",
    version="0.1.0",
    description="A simple module to find symbol positions in a grid.",
    author="Your Name",
    author_email="you@example.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    python_requires='>=3.6',
)
